#
# spec file for package mrtg
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mrtg
Version:        2.17.4
Release:        16.1
Summary:        The Multirouter Traffic Grapher
License:        GPL-2.0+
Group:          Productivity/Networking/Diagnostic
Url:            http://www.mrtg.org
Source0:        %{name}-%{version}.tar.bz2
Source1:        rateup.1
Source2:        mrtg-traffic-sum.1 
# PATCH-FIX-OPENSUSE -- install icons in openSUSE specific directory
Patch0:         mrtg-icons_path.patch
# PATCH-FIX-OPENSUSE -- do not install pod files into subdirectory
Patch1:         mrtg-pod.patch
# PATCH-FIX-UPSTREAM -- add additional switches to cfgmaker
Patch2:         mrtg-switches.patch
# PATCH-FIX-OPENSUSE -- need to find a better solution for lib64
Patch3:         mrtg-lib64hack.patch
# PATCH-FIX-OPENSUSE -- also seen in http://pkgs.fedoraproject.org/cgit/mrtg.git/plain/
Patch4:         mrtg-2.17.4-socket6-fix.patch
BuildRequires:  automake
BuildRequires:  dos2unix
%if 0%{?suse_version} > 1020
BuildRequires:  fdupes
%endif
BuildRequires:  gd-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  zlib-devel
#BuildRequires:  xorg-x11
#BuildRequires:  xorg-x11-devel
Requires:       perl = %{perl_version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define         iconsdir /srv/www/icons

%description
The Multi Router Traffic Grapher is a tool primarily used to monitor the
traffic load on network links (typically by using SNMP). MRTG generates HTML
pages containing PNG images which provide a LIVE visual representation of this
traffic. MRTG typically produces daily, weekly, monthly, and yearly graphs.

In addition to monitoring via SNMP, MRTG can also generate graphs based on
the output of any application, allowing one to generate graphs of anything
that needs monitoring (for example, CPU and memory usage, email volumes, web
hits, etc). For faster data collection, MRTG can also interface to RRDtool.

The mrtg-doc package contains additional documentation, contributed scripts 
and configuration files that used to form part of the mrtg package.



%package doc
Summary:        Documentation and contrib files for mrtg
Group:          Productivity/Networking/Diagnostic
Requires:       %{name} == %{version}

%description doc
A collection of sample scripts and configuration files for the Multi Router
Traffic Grapher (MRTG). This package contains additional documentation and 
contributed files that ship with MRTG.

%prep
%setup -q
%patch0 -p0
%patch1 -p0
%patch2 -p0
%if "%{_lib}" == "lib64"
%patch3 -p0
%endif
# mrtg-2.17.2-socket6-fix.patch
%patch4 -p1

rm -rf contrib/mrtgindex.cgi
grep -rl "/usr/local/bin/perl" contrib | xargs sed -i -e "s@/usr/local/bin/perl@/usr/bin/perl@"
grep -rl "/usr/tardis/local/gnu/bin/perl5" contrib | xargs sed -i -e "s@/usr/tardis/local/gnu/bin/perl5@/usr/bin/perl@"
grep -rl "/usr/bin/perl5" contrib | xargs sed -i -e "s@/usr/bin/perl5@/usr/bin/perl@"
grep -rl "/usr/sepp/bin/perl" contrib | xargs sed -i -e "s@/usr/sepp/bin/perl@/usr/bin/perl@"
grep -rl "/store/bin/perl" contrib | xargs sed -i -e "s@/store/bin/perl@/usr/bin/perl@"
#contrib contains binaries (ie. zipfile) which we cannot convert,
#hopefully file utility seems to mark all the text files clearly
find contrib -type f | xargs file | grep -i text | cut -d: -f1 | xargs dos2unix
find contrib -type f -name "*.html" | xargs chmod 644
# disable the line below to get executable examples in the %%doc directory
find contrib -type f | xargs chmod 644

%build
aclocal
autoconf
%configure \
	--with-gd-inc=%{_includedir}/gd
make %{?_smp_mflags}

%install
%makeinstall
mkdir -p %{buildroot}%{iconsdir}
install -m 644 doc/mrtg-[lmr].png %{buildroot}%{iconsdir}
install -d -m 755 %{buildroot}%{_datadir}/apache2/icons
install -m 644 doc/mrtg-[lmr].png %{buildroot}%{_datadir}/apache2/icons
rm -rf %{buildroot}%{_datadir}/doc
rm -rf %{buildroot}%{_datadir}/mrtg2
install -Dm0644 %{SOURCE1} %{buildroot}%{_mandir}/man1/rateup.1
install -m0644  %{SOURCE2} %{buildroot}%{_mandir}/man1/mrtg-traffic-sum.1
# install and fix documentation
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}/examples
cp -r contrib/* %{buildroot}%{_defaultdocdir}/%{name}/examples/
cp -r doc/*.{pod,txt,png} %{buildroot}%{_defaultdocdir}/%{name}/
cp -r CHANGES COPYING COPYRIGHT README THANKS %{buildroot}%{_defaultdocdir}/%{name}/
pushd %{buildroot}%{_defaultdocdir}/%{name}/
rm cfgmaker.pod indexmaker.pod mrtglib.pod
ln -s %{_bindir}/cfgmaker cfgmaker.pod
ln -s %{_bindir}/indexmaker indexmaker.pod
ln -s %{_libdir}/mrtg2/MRTG_lib.pm mrtglib.pod
popd
%if 0%{?suse_version} > 1020
%fdupes %{buildroot}%{_defaultdocdir}/%{name}
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-, root, root)
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/C*
%doc %{_defaultdocdir}/%{name}/README
%doc %{_defaultdocdir}/%{name}/THANKS
%doc %{_mandir}/man?/*
%{_bindir}/*
%{iconsdir}
%{_libdir}/mrtg2
%{_datadir}/apache2

%files doc
%defattr(-, root, root)
%dir %{_defaultdocdir}/%{name}/examples
%doc %{_defaultdocdir}/%{name}/examples/*
%doc %{_defaultdocdir}/%{name}/*.pod
%doc %{_defaultdocdir}/%{name}/*.txt
%doc %{_defaultdocdir}/%{name}/*.png

%changelog
* Tue Mar 19 2013 jw@suse.com
- mrtg-2.17.2-socket6-fix.patch
  fails to start ipv6 without.
  Seen in http://pkgs.fedoraproject.org/cgit/mrtg.git/plain
* Wed Aug 22 2012 lars@linux-schulserver.de
- re-enable the lib64 patch
- add zlib-devel to build requires
- remove xorg-x11 dependencies for now
* Thu Aug 16 2012 ro@suse.de
- add avaya as vendor to find ifAlias on updated nortel switches
* Tue Mar 27 2012 ro@suse.de
- fix SG300 issue in mrtg-switches.patch directly
* Tue Mar 27 2012 ro@suse.de
- fix lib64 issue by workaround
- support SG300 switches by cisco
* Sun Mar  4 2012 lars@linux-schulserver.de
- update to 2.17.4:
  * some address fixes to contrib
  * fixed duplicate install-sh entry in archive
  * set oid-mib-cache file for New_SNMP_util as well #106
  * prevent spurious warnings about unknonwn values of inlast outlast in mrtg
  * add the process id tmp file extensions, to guard against multiple rateup
    instances messing things up for each other. (attempt to fix #115)
  * quell warning in CnTWaLK mode #111
  * spelling fixes
  * make threshold checking more robust against incomplete information in the
    config file #113
  * support ifAlias for Vyatta gear
  * CnTWaLK should add the count and not max index
  * abort indexmaker if there is no data to be found
  * fix for big5 translation
  * in cfgmaker use ifdesc=alias only if there is actualy alias info
  * fix of a file pointer leak found by coverity scan
  * fix for kMG support in rateup
  * add support for zyxel ifAlias
  * add support for Matrix N7 Diamond
  * enable warnings in cfgmaker and fix issues ...
  * explicitly import SOCK_DGRAM and AF_UNSPEC to make ipv6 support work
  * Updated Net_SNMP_util.pm and SNMP_util.pm to latest versions
- added mrtg-switches.patch to add support for Nortel switches with
  MIB 1.3.6.1.4.1.2272.30 and also new Cisco SG-300 switches
- split out doc subpackage
- ran spec-cleaner
- remove unknown --with-rrd configure option
- use macros
- remove outdated call to suse_update_config
- added manpages for mrtg-traffic-sum and rateup
- fixed wrong interpreter lines in example scripts
- install arch dependend files in _libdir
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Feb 21 2011 vcizek@novell.com
- update to 2.17.2
  * Fix scaling when noo and noi options are used. fix for  #95
  * Stop staticly linking rateup. fix for #97
  * Only set LD_RUN_PATH if it is actually necessary. patch from #98
  * Net::SNMP only support aes128, des and 3des ... fix for cfgmaker from #99
  * Understand desc and descr in ifdesc option of cfgmaker
  * only set $args{'-maxrepetitions'} if $Net_SNMP_util::MaxRepetitions > 0
  * do not load Net_SNMP_util unless snmpv3 is requested ... fix for #75
* Thu Dec 16 2010 anicka@suse.cz
- update to 2.17.0
  * added rrdcached support
  * Added support for glob patterns in include
  * Make daemon reload cfg automatically when it changes
  * added support for Arista to cfgmaker
  * fix cfgmaker to work in mixed v1/2/3 snmp environment
  * do not strigify arguments to conversion function let eval take
  care of this
  * untaint inlast and outlast to make perl taint mode happy
* Tue Jul 27 2010 anicka@suse.cz
- update to 2.16.4
  * fix "P_DETACH" and Pod::Usage issues with perl 5.12
  * relax cfgmaker option parsing when figuring whether to test for
  highspeed counters or not.
  * fix sorting of numbered interface names index maker
  * belarusian translation for mrtg 2.16
  * three new config options to compliment the existing
  RRDRowCount option to explicitly set the size of all RRAs
  * allow to rename target in the clonedirectory option
  * add import to the require File::Copy
  * support multiple options in ifdesc and ifref setting for cfgmaker
  * teach cfgmaker about nortel switches
  * make sure rates over 4G work too
  * allow group and user option to be set to root
* Tue Jul  8 2008 anicka@suse.cz
- do not install mrtg2/Pod subdirectory because all the
  modules there are part of the perl now (bnc#403868)
* Fri Jun 27 2008 anicka@suse.cz
- update to 2.16.2
  * globally disable __DIE__ handler in eval using $^S check
  * updated to SNMP_Session 1.12
  * make SNMP_Session.pm work on windows even when a __DIE__
  handler ist installed.
* Wed Apr  9 2008 anicka@suse.cz
- update to 2.16.1
  * fix RouterUptime config with non unique targets
  * Makesure mrtg repopulates its cache only once even in fork mode
  * Added support for RRDtool based Holt-Winters aberrant behaviour
  detection.  Threshold based alerts have been enhanced to be able
  to fire based on the FAILURES RRA. Note that Holt-Winters aberrant
  behaviour detection can only be enabled on newly created RRAs.
  * when thresholds were UNboraken, the threshprogok did not run
  necessarily
  * MIB parser rewritten for better compatibility
  * allow RouterUptime to contain an explicit OID for queriing
  the uptime.
  * support for nortel passport 8600 in cfgmaker
  * Added Documentation for GeTNEXT prefix
  * Added New Prefix for Counterd SNMP Walk -> CnTWaLK (see docs)
  * Upgrade to SNMP Session 1.10
  * Updates for  Net_SNMP_util.pm   and  SNMP_util.pm
  * Fix if_is_ciscovlan condition in cfgmaker
  * Updated port syntax in documentation (based on trac entry)
* Tue Aug 28 2007 anicka@suse.cz
- do not apply dos2unix on binaries (fixes #303651)
* Thu May 24 2007 ro@suse.de
- fix some rpmlint complaints
* Fri May  4 2007 anicka@suse.cz
- update 2.15.2
  * Improve parsing reliability of indexmaker
  * Fixed deadhost detection in mrtg
  * added config option noHC for boxes that don't have HC counters
  but run SNMPv2/v3
  * Updated Net_SNMP_util module (error messages)
  * Updated Makefiles for Win32 and Netware
  * New Netware version of rateup.nlm
  * make cfgmaker detect broken snmpv1 counters more reliably
  * latest Net_SNMP_util.pm with many small fixes
  * more cfgmaker smarts and documentation for snmpv3
  * be happy even if no threshmail sending is configured
  * add install target for traffic-summer
  * fix mrtg-traffic-sum default catch expression to be
  in sync with docs
* Wed Dec 13 2006 anicka@suse.cz
- update to 2.15.0
  * Free positioning of a generated ifIndex in the OID string using·
  the magic IndexPOS keyword
  * When doing threshold checking with rrdtool, there was a very
  expensive 'getting the data back with rrdinfo and rrdfetch' cycle
  after each rrdupdate.  with rrdtool 1.2 and the updatev function
  this is not necessary anymore
  * Threshold Un-Borken Messages will only be generated when the
  value is 10%% away from the threshold. Configurable via ThreshHyst
  * New function thresholdmail lets you send an email when a threshold
  is broken. This feature talks directly to the mailserver and does
  not require any external programs.
  * New template writers helper function in cfgmaker - oid_pick. It
  tests if a device is willing to supply information regarding a
  particular oid. This makes template writing much more plesant.·
  * added new tool mrtg-traffic-sum to build traffic stats based on
  the content of your mrtg log (not rrd) files.
  * mrtg running with rrdtool can now do sub-minute resolution if the
  interval is specified like that: 0:30
  * new debug option 'prof' to see how long rrdtool spends on its
  writes
  * fixed snmpv3 support in cfgmaker
* Thu Oct  5 2006 anicka@suse.cz
- update to 2.14.7
  * Added expscale option (opposite of logscale) to emphasize
  the top end of the scale
  * bugfixes
* Mon Jul 17 2006 anicka@suse.cz
- update to 2.14.5
  * allow - in oid name
  * bugfixes
* Wed May 24 2006 anicka@suse.cz
- update to 2.14.3
  - many small fixes and improvements
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jul 13 2005 mjancar@suse.cz
- update to 2.12.2
* Mon Feb  7 2005 mjancar@suse.cz
- update to 2.11.1
* Fri Aug 13 2004 mjancar@suse.cz
- update to 2.10.15
* Thu May 13 2004 mjancar@suse.cz
- add contrib directory to %%%%doc (#40284)
* Mon Mar  8 2004 pth@suse.de
- Don't use _libdir as mrtg only installs perl scripts in there
  and mrtg, cfgmaker and indexmaker are not prepared to deal
  with a configurable lib directory (bugzilla #35456).
* Thu Feb 26 2004 mjancar@suse.cz
- update to 2.10.13
* Thu Oct 16 2003 mjancar@suse.cz
- update to 2.10.5
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Fri Jun 13 2003 mjancar@suse.cz
- fix filelist
* Tue May 27 2003 mjancar@suse.cz
- remove unpackaged files from buildroot
* Tue Apr 22 2003 vbobek@suse.cz
- update to version 2.9.29
  * bugfixes
  * small improvements
- removed obsolete fixes of icon names from the main patch
* Wed Mar 12 2003 vbobek@suse.cz
- fixed missing icons for apache2
* Sun Feb 16 2003 ro@suse.de
- really removed traces of README.SuSE
* Sat Feb 15 2003 ro@suse.de
- fixed specfile
* Fri Feb 14 2003 vbobek@suse.cz
- updated to version 2.9.25:
  * updated squid monitoring example
  * fixed indexmaker
  * cosmetic tweaks for layout
  * bug fixes
- removed obsolete README.SuSE
- fixed rights for doc files to 644
* Fri Aug 16 2002 postadal@suse.cz
- Upgrade to version 2.9.22
  * removed VERSION for ISA arry in MRTG_lib.pm ... it has no reason to be
  there, and perl 5.8 complains [Bug #17701]
  * fix for rateup rounding problems ...
* Fri Aug  9 2002 ja@suse.cz
- fixed icons instalation into apache icons directory. Mrtg and
  indexmaker can now set correct path to icons dir.
* Fri Aug  9 2002 postadal@suse.cz
- Upgrade to version 2.9.21.
* Wed May  8 2002 postadal@suse.cz
- fixed lib paths (lib64)
* Mon Feb 18 2002 tcrhak@suse.cz
- applied a patch by Klaus.Schmidinger@cadsoft.de fixing rateup.c
  to enable the usage or YTicsFactor-Parameters; bug #12847
- used %%{_libdir} macro
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Sep 19 2001 adostal@suse.cz
- create README.SuSE (fix for outputs images)
* Mon Aug  6 2001 adostal@suse.cz
- update to version 2.9.17
* Wed Mar 21 2001 ro@suse.de
- changed neededforbuild to freetype2
* Mon Feb 26 2001 cihlar@suse.cz
- update to version 2.9.10
- install data to /usr/lib/mrtg2 [#6511]
* Sat Dec  2 2000 smid@suse.cz
- new version 2.9.4
* Tue Nov 21 2000 ro@suse.de
- compile fix
* Wed Nov 15 2000 ro@suse.de
- fixed neededforbuild gdlib -> gd gd-devel
* Thu Jun  8 2000 cihlar@suse.cz
- uncomment %%clean
* Wed May 10 2000 smid@suse.cz
- upgrade to 2.8.12
- buildroot added
* Mon Oct 11 1999 ro@suse.de
- update to 2.8.8
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  9 1999 bs@suse.de
- fixed call of Check at the end of %%install section
* Tue Nov 17 1998 ro@suse.de
- use gdlib: it's been here as separate package
- adapted paths to perl5.00502
* Mon Mar  2 1998 florian@suse.de
- update to version 2.5.2
* Mon Feb  9 1998 florian@suse.de and ch@suse.de
- new package (v2.5.1)
